==> haskell-hopenpgp-2.7-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.7
id: hOpenPGP-2.7-7sNexp95xXGKrutYfsrnZU
key: hOpenPGP-2.7-7sNexp95xXGKrutYfsrnZU
license: MIT
copyright: 2012-2018  Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: https://salsa.debian.org/clint/hOpenPGP
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)
category: Codec, Data
abi: 60f505aa3732282c2e9c502dda73979a
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
import-dirs: /usr/lib/ghc-8.4.3/site-local/hOpenPGP-2.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/hOpenPGP-2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hOpenPGP-2.7
hs-libraries: HShOpenPGP-2.7-7sNexp95xXGKrutYfsrnZU
depends:
    aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1
    asn1-encoding-0.9.5-HA66FgEvKKQETY5tv3TNY9
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bifunctors-5.5.2-BrmrG1icAseGpbnKLdYeAh bytestring-0.10.8.2
    bzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x binary-0.8.5.1
    binary-conduit-1.3-KJhSHmL6NEwFDaKmj1rxe4
    conduit-1.3.0.2-IaBZFJWQ0NVERPViI4h9Gp
    conduit-extra-1.3.0-4I8uwuF5aLGDe6iB1rL3x7 containers-0.5.11.0
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    crypto-cipher-types-0.0.9-7uztzSRso0jFHBxa6bfNuo
    errors-2.3.0-7lyqder54HyGjG3QEMMISf
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    incremental-parser-0.3.1.1-KLg5MjKRGORBjoNT5lxA0p
    ixset-typed-0.4-9vdZbivuBu17zHDGJFuLko
    lens-4.16.1-HRralbhzfidGpPdYquz4lt
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs
    nettle-0.2.0-DA0OqbuesflL1n422LxtaL
    newtype-0.2-ITmrBJ3PFy1E3eiFCi9Xkw
    openpgp-asciiarmor-0.1.1-1fu74XfEfr8IQWqCUiEieH
    prettyprinter-1.2.0.1-8ZzkeAzGloQ5iYET0fLMUc
    resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG text-1.2.3.0 time-1.8.0.2
    time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    transformers-0.5.5.0 unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1=35b49024653eeb9b79eed81b6925c2b9
             asn1-encoding-0.9.5-HA66FgEvKKQETY5tv3TNY9=dc338b1f6e9e7828dde9826e57b77064
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=0cc0842c69ffec2c0f1c4a27d1f518e1
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             bifunctors-5.5.2-BrmrG1icAseGpbnKLdYeAh=fbe225a3b8a53e0101647d460bd85f03
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             bzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x=856b74462f46f0b4736f48f7d1b5cd01
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             binary-conduit-1.3-KJhSHmL6NEwFDaKmj1rxe4=7e804f82e84c155c99ba93efc769e7d1
             conduit-1.3.0.2-IaBZFJWQ0NVERPViI4h9Gp=5ba0184074fcac18e994771720a77208
             conduit-extra-1.3.0-4I8uwuF5aLGDe6iB1rL3x7=dca1734e0232a6f92078b75f08a09a91
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             crypto-cipher-types-0.0.9-7uztzSRso0jFHBxa6bfNuo=987dffa2b9cd2101713ab629e3d5fb1f
             errors-2.3.0-7lyqder54HyGjG3QEMMISf=5bf4df2d8ebcd0548f924483e94d78fc
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             incremental-parser-0.3.1.1-KLg5MjKRGORBjoNT5lxA0p=3f865ec74dfe29e8861ab4331db2c7b2
             ixset-typed-0.4-9vdZbivuBu17zHDGJFuLko=20512a38b08701fbe4660f4dcad9afe9
             lens-4.16.1-HRralbhzfidGpPdYquz4lt=cbd87dfbf6626189c53622aec5e019f0
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs=8f6673eb67ce392bdddb2c5970e7d454
             nettle-0.2.0-DA0OqbuesflL1n422LxtaL=f92b6c3a6867283efb9ebb082576f6b8
             newtype-0.2-ITmrBJ3PFy1E3eiFCi9Xkw=2753ad7f09bb3742017169e64f653c7d
             openpgp-asciiarmor-0.1.1-1fu74XfEfr8IQWqCUiEieH=9edef4ef39d51e0a9c992cb907cd94d8
             prettyprinter-1.2.0.1-8ZzkeAzGloQ5iYET0fLMUc=f92005b1ba69c2f0d229764492c8321c
             resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8=ac43be68d39189ee09e7e4402242c3d2
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=f41790414214237de89461384d016ee3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=900e31672c80ab97985a6f7a2b7fa053
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=ef1ac153a45a86b7156d838914c2c4aa
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.7-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.7
id: hOpenPGP-2.7-F8kR41qHzwd8n6fUhXYB3X
key: hOpenPGP-2.7-F8kR41qHzwd8n6fUhXYB3X
license: MIT
copyright: 2012-2018  Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: https://salsa.debian.org/clint/hOpenPGP
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)
category: Codec, Data
abi: 84c3561f62a1f55fc9dc57202d585248
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
import-dirs: /usr/lib/ghc-8.4.3/site-local/hOpenPGP-2.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/hOpenPGP-2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hOpenPGP-2.7
hs-libraries: HShOpenPGP-2.7-F8kR41qHzwd8n6fUhXYB3X
depends:
    aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1
    asn1-encoding-0.9.5-HA66FgEvKKQETY5tv3TNY9
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bifunctors-5.5.2-BrmrG1icAseGpbnKLdYeAh bytestring-0.10.8.2
    bzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x binary-0.8.5.1
    binary-conduit-1.3-KwwA4SfcRLb85rZ3NxliX8
    conduit-1.3.0.2-1hBiXB5tszl8pYcAtswbUu
    conduit-extra-1.3.0-GVcKZHuJmAnHweUkgtQJOi containers-0.5.11.0
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    crypto-cipher-types-0.0.9-7uztzSRso0jFHBxa6bfNuo
    errors-2.3.0-7lyqder54HyGjG3QEMMISf
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    incremental-parser-0.3.1.1-KLg5MjKRGORBjoNT5lxA0p
    ixset-typed-0.4-9vdZbivuBu17zHDGJFuLko
    lens-4.16.1-HRralbhzfidGpPdYquz4lt
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs
    nettle-0.2.0-DA0OqbuesflL1n422LxtaL
    newtype-0.2-ITmrBJ3PFy1E3eiFCi9Xkw
    openpgp-asciiarmor-0.1.1-1fu74XfEfr8IQWqCUiEieH
    prettyprinter-1.2.0.1-8ZzkeAzGloQ5iYET0fLMUc
    resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG text-1.2.3.0 time-1.8.0.2
    time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    transformers-0.5.5.0 unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: aeson-1.3.1.1-9XRC4e94J4n99AnBXEVUy1=35b49024653eeb9b79eed81b6925c2b9
             asn1-encoding-0.9.5-HA66FgEvKKQETY5tv3TNY9=dc338b1f6e9e7828dde9826e57b77064
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=0cc0842c69ffec2c0f1c4a27d1f518e1
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             bifunctors-5.5.2-BrmrG1icAseGpbnKLdYeAh=fbe225a3b8a53e0101647d460bd85f03
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             bzlib-0.5.0.5-I5HFtx2qcsm7rM1vX9uO9x=856b74462f46f0b4736f48f7d1b5cd01
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             binary-conduit-1.3-KwwA4SfcRLb85rZ3NxliX8=a05460c7c95f019316e429b34be07821
             conduit-1.3.0.2-1hBiXB5tszl8pYcAtswbUu=e1508db0a1776497379eb9dfad43dea0
             conduit-extra-1.3.0-GVcKZHuJmAnHweUkgtQJOi=5c74d7236fcb9207b588e4bbf52b3c29
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             crypto-cipher-types-0.0.9-7uztzSRso0jFHBxa6bfNuo=987dffa2b9cd2101713ab629e3d5fb1f
             errors-2.3.0-7lyqder54HyGjG3QEMMISf=5bf4df2d8ebcd0548f924483e94d78fc
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             incremental-parser-0.3.1.1-KLg5MjKRGORBjoNT5lxA0p=3f865ec74dfe29e8861ab4331db2c7b2
             ixset-typed-0.4-9vdZbivuBu17zHDGJFuLko=20512a38b08701fbe4660f4dcad9afe9
             lens-4.16.1-HRralbhzfidGpPdYquz4lt=cbd87dfbf6626189c53622aec5e019f0
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs=8f6673eb67ce392bdddb2c5970e7d454
             nettle-0.2.0-DA0OqbuesflL1n422LxtaL=f92b6c3a6867283efb9ebb082576f6b8
             newtype-0.2-ITmrBJ3PFy1E3eiFCi9Xkw=2753ad7f09bb3742017169e64f653c7d
             openpgp-asciiarmor-0.1.1-1fu74XfEfr8IQWqCUiEieH=9edef4ef39d51e0a9c992cb907cd94d8
             prettyprinter-1.2.0.1-8ZzkeAzGloQ5iYET0fLMUc=f92005b1ba69c2f0d229764492c8321c
             resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8=ac43be68d39189ee09e7e4402242c3d2
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=f41790414214237de89461384d016ee3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=900e31672c80ab97985a6f7a2b7fa053
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             zlib-0.6.2-HJOgVWrPGFTFgWXcvoaUGH=ef1ac153a45a86b7156d838914c2c4aa
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
